import os
import sys

def EndConnection():
    if os.path.exists(".credentials.json"):
        os.remove(".credentials.json")
        print("Terminated Successfully")
    else:
        print("Could not terminate .credentials.json")


import requests
import json


queryEnd = """query($code:String){
                    reportData{
                        report(code:$code){
                            endTime
                        }
                    }
                }"""

def Get_Data_EndTime(response, publicURL, **kwargs):
    #print(new_queryDeath)
    #print(f"event_field: \n{event_field}\n")
    #print(f"event_field: \n{reportData_field}\n")
    #print(f"event_field: \n{new_queryDeath}\n")
    data = {"query": queryEnd, "variables": kwargs}
    with requests.Session() as session:
        session.headers = response
        response = session.get(publicURL, json= data)
    return response.json()


import requests
from enum import Enum;
import json
import ReunionLog as RL
from graphql_query import Argument, Directive, Field, Operation, Query, Variable




"""class Difficulty(Enum):
    LFR = 1,
    NORMAL = 3,
    HC = 4,
    MYTHIC = 5"""
#Difficulty.Diff.value gives the value of the diff


# https://denisart.github.io/graphql-query/usage.html#arguments
episode = Variable(name="code", type="String")
event = Variable(name="Deaths", type="Deaths")
eTime = Variable(name="eTime", type="Float")
diff = Variable(name="Diff", type = "Int")
enID = Variable(name="eID", type = "Int")

arg_episode = [Argument(name="code", value=episode)]
arg_event = [Argument(name="dataType", value="Deaths"), Argument(name = "difficulty", value=Variable(name="Diff", type = "Int")), Argument(name = "encounterID", value = Variable(name="eID", type="Int")), Argument(name="endTime", value=Variable(name="eTime", type="String")), Argument(name = "wipeCutoff", value=3), Argument(name="useAbilityIDs", value="false")]

queryDeath = Query(
    name="reportData",
    fields=[
        Field(
            name="report",
            arguments=arg_episode,
            fields=[
                Field(
                    name="events",
                    arguments=arg_event,
                    fields=["data"]
                )
            ]
        )
    ]
)
operation = Operation(
    type="query",
    variables=[episode, eTime, diff, enID],
    queries=[queryDeath]
)


"""Gets the data 'events' from GraphQL api. Require response, auth-url and event string"""
def Get_Data_EventDeath(response, publicURL, diff, **kwargs):
    difficultyVal = diff.value
    """match diff:
        case Difficulty.LFR.value:
            break;
        case Difficulty.NORMAL.value:
            break;
        case Difficulty.HC.value:
            break;
        case Difficulty.MYTHIC.value:
            break;
        case _:
            break;"""

    if kwargs == {}:
        print("---Assuming default kwargs---");
        kwargs = {'code' : "fj6Pp7TVkaW2KXzB", 'eTime':999999999999}
    print(kwargs)

    data = {"query": operation.render(), "variables": kwargs}
    with requests.Session() as session:
        session.headers = response
        response = session.get(publicURL, json= data)
    return response.json()





#Authentication
from ReunionLog.OAuth.Authentication import Retrieve_Headers

#End
from ReunionLog.OAuth.EndConnection import EndConnection

#Abilities
from ReunionLog.Report.ReportAbilities import Get_AbilityList #Python List
from ReunionLog.Report.ReportAbilities import Get_Data_Ability #JSON Data

#Damage Done
from ReunionLog.Report.ReportEventsDamageDone import Get_Data_EventDamageDone #JSON Data

#Death
from ReunionLog.Report.ReportEventsDeath import Get_Data_EventDeath #JSON Data

#Interrupts
from ReunionLog.Report.ReportEventsInterrupts import Get_Data_EventInterrupts #JSON Data

#Names
from ReunionLog.Report.ReportNames import Get_Data_Name #JSON Data
from ReunionLog.Report.ReportNames import Get_NameList #Python List

#Times
from ReunionLog.Report.ReportStartTime import Get_Data_StartTime
from ReunionLog.Report.ReportEndTime import Get_Data_EndTime
